summaryrefslogtreecommitdiff
path: root/include/asterisk/http.h
diff options
context:
space:
mode:
authorLuigi Rizzo <rizzo@icir.org>2006-12-16 09:33:31 +0000
committerLuigi Rizzo <rizzo@icir.org>2006-12-16 09:33:31 +0000
commit20b382cfff4a276156d1bac863ae3b6cc9d2a384 (patch)
tree27d106a85ab51a1a3fce3af1cf043e890d86ca07 /include/asterisk/http.h
parentb2bd05ee839d4b91730f9b65bd95706b582f2ae5 (diff)
replace ast_build_string() with ast_str_*() functions.
This makes the code easier to follow and saves some copies to intermediate buffers. git-svn-id: https://origsvn.digium.com/svn/asterisk/trunk@48515 65c4cc65-6c06-0410-ace0-fbb531ad65f3
Diffstat (limited to 'include/asterisk/http.h')
-rw-r--r--include/asterisk/http.h8
1 files changed, 3 insertions, 5 deletions
diff --git a/include/asterisk/http.h b/include/asterisk/http.h
index bfd39c039..c3e2ba0fa 100644
--- a/include/asterisk/http.h
+++ b/include/asterisk/http.h
@@ -144,7 +144,7 @@ int ssl_setup(struct tls_config *cfg);
The return value may include additional headers at the front and MUST include a blank
line with \r\n to provide separation between user headers and content (even if no
content is specified) */
-typedef char *(*ast_http_callback)(struct sockaddr_in *requestor, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength);
+typedef struct ast_str *(*ast_http_callback)(struct sockaddr_in *requestor, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength);
struct ast_http_uri {
struct ast_http_uri *next;
@@ -157,14 +157,12 @@ struct ast_http_uri {
/*! \brief Link into the Asterisk HTTP server */
int ast_http_uri_link(struct ast_http_uri *urihandler);
-/*! \brief Return a malloc()'d string containing an HTTP error message */
-char *ast_http_error(int status, const char *title, const char *extra_header, const char *text);
+/*! \brief Return an ast_str malloc()'d string containing an HTTP error message */
+struct ast_str *ast_http_error(int status, const char *title, const char *extra_header, const char *text);
/*! \brief Destroy an HTTP server */
void ast_http_uri_unlink(struct ast_http_uri *urihandler);
-char *ast_http_setcookie(const char *var, const char *val, int expires, char *buf, size_t buflen);
-
int ast_http_init(void);
int ast_http_reload(void);